@@ -282,7 +282,7 @@ static bool addToXbel(const QUrl &url, const QString &desktopEntryName, KRecentD
                     foundMatchingBookmark = true;
 
                     QXmlStreamAttributes newAttributes;
-                    for (const QXmlStreamAttribute &old : attributes) {
+                    for (const QXmlStreamAttribute &old : std::as_const(attributes)) {
                         if (old.name() == modifiedAttribute) {
                             continue;
                         }
@@ -564,7 +564,7 @@ void KRecentDocument::removeFile(const QUrl &url)
 
     auto xbelTags = document.elementsByTagName(xbelTag);
     if (xbelTags.length() != 1) {
-        qCWarning(KIO_CORE) << "Invalid Xbel file, missing xbel elememt";
+        qCWarning(KIO_CORE) << "Invalid Xbel file, missing xbel element";
         return;
     }
     auto xbelElement = xbelTags.item(0);
