@@ -17,6 +17,7 @@
 #include "kdiroperatoriconview_p.h"
 #include "kdirsortfilterproxymodel.h"
 #include "kfileitem.h"
+#include "kfileitemselectionemblem.h"
 #include "kfilemetapreview_p.h"
 #include "knewfilemenu.h"
 #include "kpreviewwidgetbase.h"
@@ -39,11 +40,14 @@
 #include <KUrlMimeData>
 #include <kfileitemdelegate.h>
 #include <kfilepreviewgenerator.h>
+#include <kio/askuseractioninterface.h>
 #include <kio/copyjob.h>
 #include <kio/deletejob.h>
 #include <kio/deleteortrashjob.h>
 #include <kio/jobuidelegate.h>
+#include <kio/jobuidelegatefactory.h>
 #include <kio/previewjob.h>
+#include <kio/widgetsaskuseractionhandler.h>
 #include <kpropertiesdialog.h>
 
 #include <QActionGroup>
@@ -220,6 +224,7 @@ public:
     bool m_showOpenWithActions = false;
     bool m_isTouchEvent = false;
     bool m_isTouchDrag = false;
+    bool m_keyNavigation = false;
 
     QList<QUrl> m_itemsToBeSetAsCurrent;
     QStringList m_supportedSchemes;
@@ -420,6 +425,7 @@ void KDirOperator::updateSelectionDependentActions()
     action(KDirOperator::Properties)->setEnabled(hasSelection);
 }
 
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(6, 19)
 void KDirOperator::setPreviewWidget(KPreviewWidgetBase *w)
 {
     const bool showPreview = (w != nullptr);
@@ -441,6 +447,7 @@ void KDirOperator::setPreviewWidget(KPreviewWidgetBase *w)
     previewAction->setChecked(showPreview);
     setViewMode(static_cast<KFile::FileView>(d->m_viewKind));
 }
+#endif
 
 KFileItemList KDirOperator::selectedItems() const
 {
@@ -710,6 +717,7 @@ void KDirOperator::mkdir()
     d->m_newFileMenu->createDirectory();
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(6, 15)
 KIO::DeleteJob *KDirOperator::del(const KFileItemList &items, QWidget *parent, bool ask, bool showProgress)
 {
     if (items.isEmpty()) {
@@ -740,6 +748,7 @@ KIO::DeleteJob *KDirOperator::del(const KFileItemList &items, QWidget *parent, b
 
     return nullptr;
 }
+#endif
 
 void KDirOperator::deleteSelected()
 {
@@ -754,6 +763,7 @@ void KDirOperator::deleteSelected()
     deleteJob->start();
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(6, 15)
 KIO::CopyJob *KDirOperator::trash(const KFileItemList &items, QWidget *parent, bool ask, bool showProgress)
 {
     if (items.isEmpty()) {
@@ -780,6 +790,7 @@ KIO::CopyJob *KDirOperator::trash(const KFileItemList &items, QWidget *parent, b
 
     return nullptr;
 }
+#endif
 
 KFilePreviewGenerator *KDirOperator::previewGenerator() const
 {
@@ -995,6 +1006,11 @@ int KDirOperatorPrivate::sortColumn() const
 
 Qt::SortOrder KDirOperatorPrivate::sortOrder() const
 {
+    // Reverse whatever was applied to time sorting, since reversed by default is nicer
+    if (m_sorting & QDir::Time) {
+        return (m_sorting & QDir::Reversed) ? Qt::AscendingOrder : Qt::DescendingOrder;
+    }
+
     return (m_sorting & QDir::Reversed) ? Qt::DescendingOrder : Qt::AscendingOrder;
 }
 
@@ -1011,20 +1027,6 @@ void KDirOperatorPrivate::updateSorting(QDir::SortFlags sort)
     m_proxyModel->setSortFoldersFirst(m_sorting & QDir::DirsFirst);
     m_proxyModel->sort(sortColumn(), sortOrder());
 
-    // TODO: The headers from QTreeView don't take care about a sorting
-    // change of the proxy model hence they must be updated the manually.
-    // This is done here by a qobject_cast, but it would be nicer to:
-    // - provide a signal 'sortingChanged()'
-    // - connect KDirOperatorDetailView() with this signal and update the
-    //   header internally
-    QTreeView *treeView = qobject_cast<QTreeView *>(m_itemView);
-    if (treeView != nullptr) {
-        QHeaderView *headerView = treeView->header();
-        headerView->blockSignals(true);
-        headerView->setSortIndicator(sortColumn(), sortOrder());
-        headerView->blockSignals(false);
-    }
-
     assureVisibleSelection();
 }
 
@@ -1243,6 +1245,11 @@ void KDirOperator::showOpenWithActions(bool enable)
     d->m_showOpenWithActions = enable;
 }
 
+bool KDirOperator::usingKeyNavigation()
+{
+    return d->m_keyNavigation;
+}
+
 void KDirOperator::changeEvent(QEvent *event)
 {
     QWidget::changeEvent(event);
@@ -1260,9 +1267,13 @@ bool KDirOperator::eventFilter(QObject *watched, QEvent *event)
         if (d->m_isTouchEvent) {
             return true;
         }
-        if (d->m_preview && !d->m_preview->isHidden()) {
-            const QModelIndex hoveredIndex = d->m_itemView->indexAt(d->m_itemView->viewport()->mapFromGlobal(QCursor::pos()));
 
+        const QModelIndex hoveredIndex = d->m_itemView->indexAt(d->m_itemView->viewport()->mapFromGlobal(QCursor::pos()));
+        if (hoveredIndex.isValid()) {
+            KFileItemSelectionEmblem(d->m_itemView, hoveredIndex, this).updateSelectionEmblemRectForIndex(iconSize());
+        }
+
+        if (d->m_preview && !d->m_preview->isHidden()) {
             if (d->m_lastHoveredIndex == hoveredIndex) {
                 return QWidget::eventFilter(watched, event);
             }
@@ -1424,6 +1435,19 @@ bool KDirOperator::eventFilter(QObject *watched, QEvent *event)
                 return true;
             }
         }
+        // Only use tab key to escape the view navigation
+        if (evt->key() == Qt::Key_Tab) {
+            d->m_keyNavigation = false;
+            d->slotSelectionChanged();
+            // When saving we need to return here,
+            // otherwise we skip over the next item with our tab press
+            // since we focus on that item in slotSelectionChanged
+            if (d->m_isSaving) {
+                return true;
+            }
+        } else {
+            d->m_keyNavigation = true;
+        }
         break;
     }
     case QEvent::Resize: {
@@ -1510,11 +1534,11 @@ QAbstractItemView *KDirOperator::createView(QWidget *parent, KFile::FileView vie
 {
     QAbstractItemView *itemView = nullptr;
     if (KFile::isDetailView(viewKind) || KFile::isTreeView(viewKind) || KFile::isDetailTreeView(viewKind)) {
-        KDirOperatorDetailView *detailView = new KDirOperatorDetailView(parent);
+        KDirOperatorDetailView *detailView = new KDirOperatorDetailView(this, parent);
         detailView->setViewMode(viewKind);
         itemView = detailView;
     } else {
-        itemView = new KDirOperatorIconView(parent, decorationPosition());
+        itemView = new KDirOperatorIconView(this, parent, decorationPosition());
     }
 
     return itemView;
@@ -1828,6 +1852,7 @@ void KDirOperator::selectFile(const KFileItem &item)
     QApplication::restoreOverrideCursor();
 
     Q_EMIT fileSelected(item);
+    d->m_keyNavigation = false;
 }
 
 void KDirOperator::highlightFile(const KFileItem &item)
@@ -1837,6 +1862,7 @@ void KDirOperator::highlightFile(const KFileItem &item)
     }
 
     Q_EMIT fileHighlighted(item);
+    d->m_keyNavigation = false;
 }
 
 void KDirOperator::setCurrentItem(const QUrl &url)
@@ -2329,8 +2355,8 @@ void KDirOperator::updateSortActions()
         ascending->setText(i18nc("Sort ascending", "A-Z"));
     } else if (KFile::isSortByDate(d->m_sorting)) {
         action(KDirOperator::SortByDate)->setChecked(true);
-        descending->setText(i18nc("Sort descending", "Newest First"));
-        ascending->setText(i18nc("Sort ascending", "Oldest First"));
+        descending->setText(i18nc("Sort ascending", "Oldest First"));
+        ascending->setText(i18nc("Sort descending", "Newest First"));
     } else if (KFile::isSortBySize(d->m_sorting)) {
         action(KDirOperator::SortBySize)->setChecked(true);
         descending->setText(i18nc("Sort descending", "Largest First"));
