@@ -81,7 +81,7 @@ public:
     void applyUncommittedUrl(ApplyUrlMethod method);
     void slotApplyUrl(QUrl url);
 
-    // Returns the URI if "text" matched a URI filter (i.e. was fitlered),
+    // Returns the URI if "text" matched a URI filter (i.e. was filtered),
     // otherwise returns nullopt.
     std::optional<QUrl> checkFilters(const QString &text);
 
@@ -891,7 +891,7 @@ void KUrlNavigatorPrivate::updateButtonVisibility()
     }
 
     auto lastButton = m_navButtons.last();
-    for (const auto &button : m_navButtons) {
+    for (const auto &button : std::as_const(m_navButtons)) {
         if (button != lastButton) {
             button->setDrawSeparator(true);
         } else {
@@ -1437,11 +1437,6 @@ void KUrlNavigator::paintEvent(QPaintEvent *event)
             option.palette.setColor(QPalette::Base, palette().alternateBase().color());
         }
         style()->drawPrimitive(QStyle::PE_FrameLineEdit, &option, &painter, this);
-    } else {
-        // Draw primitive only for the input field
-        if (d->m_editable) {
-            style()->drawPrimitive(QStyle::PE_FrameLineEdit, &option, &painter, this);
-        }
     }
 }
 
