@@ -88,6 +88,7 @@ static void modifyEnv(KProcess &process, QProcessEnvironment mod)
 KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
                                                 const QString &serviceEntryPath,
                                                 const QList<QUrl> &urls,
+                                                const QString &actionName,
                                                 KIO::ApplicationLauncherJob::RunFlags flags,
                                                 const QString &suggestedFileName,
                                                 const QByteArray &asn)
@@ -103,9 +104,12 @@ KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
     const bool notYetSupportedOpenActivationNeeded = !urls.isEmpty();
     if (!notYetSupportedOpenActivationNeeded && DBusActivationRunner::activationPossible(service, flags, suggestedFileName)) {
         const auto actions = service->actions();
-        auto action = std::find_if(actions.cbegin(), actions.cend(), [service](const KServiceAction &action) {
-            return action.exec() == service->exec();
+        auto action = std::find_if(actions.cbegin(), actions.cend(), [actionName](const KServiceAction &action) {
+            return action.name() == actionName;
         });
+        if (!actionName.isEmpty() && action == actions.cend()) {
+            qCWarning(KIO_GUI) << "Requested action" << actionName << "cannot be found for" << service->name();
+        }
         instance = new DBusActivationRunner(action != actions.cend() ? action->name() : QString());
     } else {
         instance = makeInstance();
@@ -310,29 +314,20 @@ void KProcessRunner::init(const KService::Ptr &service, const QString &serviceEn
                 window = qGuiApp->allWindows().constFirst();
             }
             if (window) {
-                const int launchedSerial = KWaylandExtras::lastInputSerial(window);
                 m_waitingForXdgToken = true;
-                connect(
-                    KWaylandExtras::self(),
-                    &KWaylandExtras::xdgActivationTokenArrived,
-                    m_process.get(),
-                    [this, launchedSerial](int tokenSerial, const QString &token) {
-                        if (tokenSerial == launchedSerial) {
-                            m_process->setEnv(QStringLiteral("XDG_ACTIVATION_TOKEN"), token);
-                            m_waitingForXdgToken = false;
-                            startProcess();
-                        }
-                    },
-                    Qt::SingleShotConnection);
-                KWaylandExtras::requestXdgActivationToken(window, launchedSerial, resolveServiceAlias());
+                m_xdgActivationTokenFuture = KWaylandExtras::xdgActivationToken(window, resolveServiceAlias());
+                m_xdgActivationTokenFuture.then(this, [this](const QString &token) {
+                    m_process->setEnv(QStringLiteral("XDG_ACTIVATION_TOKEN"), token);
+                    m_waitingForXdgToken = false;
+                    startProcess();
+                });
+                return;
             }
         }
     }
 #endif
 
-    if (!m_waitingForXdgToken) {
-        startProcess();
-    }
+    startProcess();
 }
 
 void ForkingProcessRunner::startProcess()
