@@ -1129,10 +1129,11 @@ QString TrashImpl::trashForMountPoint(const QString &topdir, bool createIfNeeded
 #endif
             const QByteArray trashDir_c = QFile::encodeName(trashDir);
             if (QT_LSTAT(trashDir_c.constData(), &buff) == 0) {
-                if ((buff.st_uid == uid) // must be owned by user
-                    && (S_ISDIR(buff.st_mode)) // must be a dir
+                if ((S_ISDIR(buff.st_mode)) // must be a dir
                     && (!S_ISLNK(buff.st_mode)) // not a symlink
-                    && (buff.st_mode & 0777) == 0700) { // rwx for user
+                    // we use access() because checking mode isn't sufficient for remote directories
+                    && (::access(trashDir_c.constData(), W_OK | X_OK) == 0) // must be user-writable
+                ) {
 #ifdef Q_OS_OSX
                     trashDir += QStringLiteral("/KDE.trash");
 #endif
@@ -1152,11 +1153,10 @@ QString TrashImpl::trashForMountPoint(const QString &topdir, bool createIfNeeded
     const QString trashDir = topdir + QLatin1String("/.Trash-") + QString::number(uid);
     const QByteArray trashDir_c = QFile::encodeName(trashDir);
     if (QT_LSTAT(trashDir_c.constData(), &buff) == 0) {
-        if ((buff.st_uid == uid) // must be owned by user
-            && S_ISDIR(buff.st_mode) // must be a dir
-            && !S_ISLNK(buff.st_mode) // not a symlink
-            && ((buff.st_mode & 0700) == 0700)) { // and we need write access to it
-
+        if ((S_ISDIR(buff.st_mode)) // must be a dir
+            && (!S_ISLNK(buff.st_mode)) // not a symlink
+            && (::access(trashDir_c.constData(), W_OK | X_OK) == 0) // and we need write access to it
+        ) {
             if (buff.st_dev == m_homeDevice) // bind mount, maybe
                 return QString();
             if (checkTrashSubdirs(trashDir_c)) {
@@ -1322,11 +1322,12 @@ bool TrashImpl::adaptTrashSize(const QString &origPath, int trashId)
     }
 
     // before we start to remove any files from the trash,
-    // check whether the new file will fit into the trash
-    // at all...
+    // check whether the new file can ever fit into the trash at all...
     const qint64 partitionSize = util.size();
+    const qint64 totalMaxSizeAllowed = qRound(partitionSize * percent / 100.0);
 
-    if ((util.usage(partitionSize + additionalSize)) >= percent) {
+    // Only reject if the new file itself is larger than the maximum allowed trash size
+    if (additionalSize > totalMaxSizeAllowed) {
         m_lastErrorCode = KIO::ERR_TRASH_FILE_TOO_LARGE;
         m_lastErrorMessage = KIO::buildErrorString(m_lastErrorCode, {});
         return false;
