@@ -17,6 +17,7 @@
 #include <kio/fileundomanager.h>
 #include <kio/simplejob.h>
 #include <kio/statjob.h>
+#include <kio/copyjob.h>
 
 #include <QBitArray>
 #include <QDebug>
@@ -101,10 +102,21 @@ public:
         m_preview = icn;
     }
 
+    bool previewHandlesSequences()
+    {
+        return m_previewHandlesSequences;
+    }
+
+    void setPreviewHandlesSequences(bool handlesSequences)
+    {
+        m_previewHandlesSequences = handlesSequences;
+    }
+
 private:
     KFileItem m_item;
     KDirModelDirNode *const m_parent;
     QIcon m_preview;
+    bool m_previewHandlesSequences = true; // First sequence is always allowed
 };
 
 // Specialization for directory nodes
@@ -259,7 +271,7 @@ public:
 
     QUrl urlForNode(KDirModelNode *node) const
     {
-        /**
+        /*
          * Queries and fragments are removed from the URL, so that the URL of
          * child items really starts with the URL of the parent.
          *
@@ -915,6 +927,11 @@ QVariant KDirModel::data(const QModelIndex &index, int role) const
                 }
             }
             break;
+        case HandleSequencesRole:
+            if (index.column() == Name) {
+                return node->previewHandlesSequences();
+            }
+            break;
         case Qt::TextAlignmentRole:
             if (index.column() == Size) {
                 // use a right alignment for L2R and R2L languages
@@ -1010,7 +1027,7 @@ bool KDirModel::setData(const QModelIndex &index, const QVariant &value, int rol
             }
             QUrl newUrl = item.url().adjusted(QUrl::RemoveFilename);
             newUrl.setPath(newUrl.path() + KIO::encodeFileName(newName));
-            KIO::Job *job = KIO::rename(item.url(), newUrl, item.url().isLocalFile() ? KIO::HideProgressInfo : KIO::DefaultFlags);
+            KIO::Job *job = KIO::moveAs(item.url(), newUrl, item.url().isLocalFile() ? KIO::HideProgressInfo : KIO::DefaultFlags);
             job->uiDelegate()->setAutoErrorHandlingEnabled(true);
             // undo handling
             KIO::FileUndoManager::self()->recordJob(KIO::FileUndoManager::Rename, QList<QUrl>() << item.url(), newUrl, job);
@@ -1034,6 +1051,14 @@ bool KDirModel::setData(const QModelIndex &index, const QVariant &value, int rol
             return true;
         }
         break;
+    case HandleSequencesRole:
+        if (index.column() == Name) {
+            KDirModelNode *node = static_cast<KDirModelNode *>(index.internalPointer());
+            Q_ASSERT(node);
+            node->setPreviewHandlesSequences(value.toBool());
+            return true;
+        }
+        break;
     default:
         break;
     }
