@@ -194,7 +194,7 @@ int KFileItemActionsPrivate::insertServices(const ServiceList &list, QMenu *menu
     // Sort each group
     for (ServiceList &group : allGroups) {
         std::sort(group.begin(), group.end(), [](const KDesktopFileAction &a1, const KDesktopFileAction &a2) {
-            return a1.name() < a2.name();
+            return a1.actionsKey() < a2.actionsKey();
         });
     }
 
@@ -233,7 +233,7 @@ int KFileItemActionsPrivate::insertServices(const ServiceList &list, QMenu *menu
 void KFileItemActionsPrivate::slotExecuteService(QAction *act)
 {
     const KDesktopFileAction serviceAction = act->data().value<KDesktopFileAction>();
-    if (KAuthorized::authorizeAction(serviceAction.name())) {
+    if (KAuthorized::authorizeAction(serviceAction.actionsKey())) {
         auto *job = new KIO::ApplicationLauncherJob(serviceAction);
         job->setUrls(m_props.urlList());
         job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_parentWidget));
@@ -508,7 +508,6 @@ KFileItemActionsPrivate::addServiceActionsTo(QMenu *mainMenu, const QList<QActio
 
     const KConfigGroup showGroup = m_config.group(QStringLiteral("Show"));
 
-    const QMimeDatabase db;
     const QStringList files = serviceMenuFilePaths();
     for (const QString &file : files) {
         const KDesktopFile desktopFile(file);
@@ -735,30 +734,17 @@ void KFileItemActionsPrivate::insertOpenWithActionsTo(QAction *before, QMenu *to
                 QDBusConnection::sessionBus().asyncCall(message);
             }
         };
+        connect(openWithAction, &QAction::triggered, this, [this, sendMessage] {
 #if HAVE_WAYLAND
-        if (KWindowSystem::isPlatformWayland() && !qGuiApp->allWindows().isEmpty()) {
-            QObject::connect(openWithAction, &QAction::triggered, this, [] {
+            if (KWindowSystem::isPlatformWayland() && !qGuiApp->allWindows().isEmpty()) {
                 auto window = qGuiApp->allWindows().constFirst();
-                KWaylandExtras::requestXdgActivationToken(window, KWaylandExtras::lastInputSerial(window), {});
-            });
-            QObject::connect(
-                KWaylandExtras::self(),
-                &KWaylandExtras::xdgActivationTokenArrived,
-                this,
-                [sendMessage](int, const QString &token) {
-                    sendMessage(token);
-                },
-                Qt::SingleShotConnection);
-        } else {
-            QObject::connect(openWithAction, &QAction::triggered, this, [sendMessage] {
-                sendMessage({});
-            });
-        }
-#else
-        QObject::connect(openWithAction, &QAction::triggered, this, [sendMessage] {
+                auto tokenFuture = KWaylandExtras::xdgActivationToken(window, {});
+                tokenFuture.then(this, sendMessage);
+                return;
+            }
+#endif
             sendMessage({});
         });
-#endif
         topMenu->insertAction(before, openWithAction);
         return;
     }
