@@ -158,7 +158,7 @@ static CompareFilesResult compareFiles(const QString &filepath, const QString &s
     }
 }
 
-/** @internal */
+/*! \internal */
 class Q_DECL_HIDDEN RenameDialog::RenameDialogPrivate
 {
 public:
@@ -368,6 +368,7 @@ RenameDialog::RenameDialog(QWidget *parent,
                             KShell::tildeCollapse(d->dest.toDisplayString(QUrl::PreferLocalFile)));
         }
         auto *questionLabel = new QLabel(question, this);
+        questionLabel->setWordWrap(true);
         questionLabel->setAlignment(Qt::AlignHCenter);
         gridLayout->addWidget(questionLabel, gridRow, 0, 1, 4); // takes the complete first line
 
